@@ -3,7 +3,7 @@
 # Copyright (c), The AiiDA team. All rights reserved.                     #
 # This file is part of the AiiDA code.                                    #
 #                                                                         #
-# The code is hosted on GitHub at https://github.com/aiidateam/aiida_core #
+# The code is hosted on GitHub at https://github.com/aiidateam/aiida-core #
 # For further information on the license, see the LICENSE.txt file        #
 # For further information please visit http://www.aiida.net               #
 ###########################################################################
@@ -30,8 +30,8 @@ depends_on = None
 def upgrade():
     op.drop_table('db_dbpath')
     conn = op.get_bind()
-    conn.execute("DROP TRIGGER IF EXISTS autoupdate_tc ON db_dblink")
-    conn.execute("DROP FUNCTION IF EXISTS update_tc()")
+    conn.execute('DROP TRIGGER IF EXISTS autoupdate_tc ON db_dblink')
+    conn.execute('DROP FUNCTION IF EXISTS update_tc()')
 
 
 def downgrade():
@@ -43,9 +43,9 @@ def downgrade():
     sa.Column('entry_edge_id', sa.INTEGER(), autoincrement=False, nullable=True),
     sa.Column('direct_edge_id', sa.INTEGER(), autoincrement=False, nullable=True),
     sa.Column('exit_edge_id', sa.INTEGER(), autoincrement=False, nullable=True),
-    sa.ForeignKeyConstraint(['child_id'], [u'db_dbnode.id'], name=u'db_dbpath_child_id_fkey', initially=u'DEFERRED', deferrable=True),
-    sa.ForeignKeyConstraint(['parent_id'], [u'db_dbnode.id'], name=u'db_dbpath_parent_id_fkey', initially=u'DEFERRED', deferrable=True),
-    sa.PrimaryKeyConstraint('id', name=u'db_dbpath_pkey')
+    sa.ForeignKeyConstraint(['child_id'], ['db_dbnode.id'], name='db_dbpath_child_id_fkey', initially='DEFERRED', deferrable=True),
+    sa.ForeignKeyConstraint(['parent_id'], ['db_dbnode.id'], name='db_dbpath_parent_id_fkey', initially='DEFERRED', deferrable=True),
+    sa.PrimaryKeyConstraint('id', name='db_dbpath_pkey')
     )
     # I get the session using the alembic connection
     # (Keep in mind that alembic uses the AiiDA SQLA
