@@ -12,11 +12,12 @@
 from enum import Enum
 import traceback
 import urllib.request
+
 import click
 
 from aiida.cmdline.commands.cmd_verdi import verdi
 from aiida.cmdline.params import options
-from aiida.cmdline.params.types import GroupParamType, ImportPath
+from aiida.cmdline.params.types import GroupParamType, PathOrUrl
 from aiida.cmdline.utils import decorators, echo
 
 EXTRAS_MODE_EXISTING = ['keep_existing', 'update_existing', 'mirror', 'none', 'ask']
@@ -34,6 +35,45 @@ class ExtrasImportCode(Enum):
     ask = 'kca'
 
 
+def _echo_error(  # pylint: disable=unused-argument
+    message, non_interactive, more_archives, raised_exception, **kwargs
+):
+    """Utility function to help write an error message for ``verdi import``
+
+    :param message: Message following red-colored, bold "Error:".
+    :type message: str
+    :param non_interactive: Whether or not the user should be asked for input for any reason.
+    :type non_interactive: bool
+    :param more_archives: Whether or not there are more archives to import.
+    :type more_archives: bool
+    :param raised_exception: Exception raised during error.
+    :type raised_exception: `Exception`
+    """
+    from aiida.tools.importexport import close_progress_bar, IMPORT_LOGGER
+
+    # Close progress bar, if it exists
+    close_progress_bar(leave=False)
+
+    IMPORT_LOGGER.debug('%s', traceback.format_exc())
+
+    exception = '{}: {}'.format(raised_exception.__class__.__name__, str(raised_exception))
+
+    echo.echo_error(message)
+    echo.echo(exception)
+
+    if more_archives:
+        # There are more archives to go through
+        if non_interactive:
+            # Continue to next archive
+            pass
+        else:
+            # Ask if one should continue to next archive
+            click.confirm('Do you want to continue?', abort=True)
+    else:
+        # There are no more archives
+        click.Abort()
+
+
 def _try_import(migration_performed, file_to_import, archive, group, migration, non_interactive, **kwargs):
     """Utility function for `verdi import` to try to import archive
 
@@ -66,8 +106,12 @@ def _try_import(migration_performed, file_to_import, archive, group, migration,
     except IncompatibleArchiveVersionError as exception:
         if migration_performed:
             # Migration has been performed, something is still wrong
-            crit_message = '{} has been migrated, but it still cannot be imported.\n{}'.format(archive, exception)
-            echo.echo_critical(crit_message)
+            _echo_error(
+                '{} has been migrated, but it still cannot be imported'.format(archive),
+                non_interactive=non_interactive,
+                raised_exception=exception,
+                **kwargs
+            )
         else:
             # Migration has not yet been tried.
             if migration:
@@ -85,18 +129,20 @@ def _try_import(migration_performed, file_to_import, archive, group, migration,
             else:
                 # Abort
                 echo.echo_critical(str(exception))
-    except Exception:
-        echo.echo_error('an exception occurred while importing the archive {}'.format(archive))
-        echo.echo(traceback.format_exc())
-        if not non_interactive:
-            click.confirm('do you want to continue?', abort=True)
+    except Exception as exception:
+        _echo_error(
+            'an exception occurred while importing the archive {}'.format(archive),
+            non_interactive=non_interactive,
+            raised_exception=exception,
+            **kwargs
+        )
     else:
         echo.echo_success('imported archive {}'.format(archive))
 
     return migrate_archive
 
 
-def _migrate_archive(ctx, temp_folder, file_to_import, archive, non_interactive, **kwargs):  # pylint: disable=unused-argument
+def _migrate_archive(ctx, temp_folder, file_to_import, archive, non_interactive, more_archives, silent, **kwargs):  # pylint: disable=unused-argument
     """Utility function for `verdi import` to migrate archive
     Invoke click command `verdi export migrate`, passing in the archive,
     outputting the migrated archive in a temporary SandboxFolder.
@@ -107,6 +153,8 @@ def _migrate_archive(ctx, temp_folder, file_to_import, archive, non_interactive,
     :param file_to_import: Absolute path, including filename, of file to be migrated.
     :param archive: Filename of archive to be migrated, and later attempted imported.
     :param non_interactive: Whether or not the user should be asked for input for any reason.
+    :param more_archives: Whether or not there are more archives to be imported.
+    :param silent: Suppress console messages.
     :return: Absolute path to migrated archive within SandboxFolder.
     """
     from aiida.cmdline.commands.cmd_export import migrate
@@ -120,24 +168,25 @@ def _migrate_archive(ctx, temp_folder, file_to_import, archive, non_interactive,
     # Migration
     try:
         ctx.invoke(
-            migrate, input_file=file_to_import, output_file=temp_folder.get_abs_path(temp_out_file), silent=False
+            migrate, input_file=file_to_import, output_file=temp_folder.get_abs_path(temp_out_file), silent=silent
         )
-    except Exception:
-        echo.echo_error(
+    except Exception as exception:
+        _echo_error(
             'an exception occurred while migrating the archive {}.\n'
-            "Use 'verdi export migrate' to update this export file.".format(archive)
+            "Use 'verdi export migrate' to update this export file.".format(archive),
+            non_interactive=non_interactive,
+            more_archives=more_archives,
+            raised_exception=exception
         )
-        echo.echo(traceback.format_exc())
-        if not non_interactive:
-            click.confirm('do you want to continue?', abort=True)
     else:
-        echo.echo_success('archive migrated, proceeding with import')
+        # Success
+        echo.echo_info('proceeding with import')
 
         return temp_folder.get_abs_path(temp_out_file)
 
 
 @verdi.command('import')
-@click.argument('archives', nargs=-1, type=ImportPath(exists=True, readable=True))
+@click.argument('archives', nargs=-1, type=PathOrUrl(exists=True, readable=True))
 @click.option(
     '-w',
     '--webpages',
@@ -197,7 +246,6 @@ def cmd_import(
 
     The archive can be specified by its relative or absolute file path, or its HTTP URL.
     """
-
     from aiida.common.folders import SandboxFolder
     from aiida.tools.importexport.common.utils import get_valid_import_links
 
@@ -217,11 +265,13 @@ def cmd_import(
             try:
                 echo.echo_info('retrieving archive URLS from {}'.format(webpage))
                 urls = get_valid_import_links(webpage)
-            except Exception:
-                echo.echo_error('an exception occurred while trying to discover archives at URL {}'.format(webpage))
-                echo.echo(traceback.format_exc())
-                if not non_interactive:
-                    click.confirm('do you want to continue?', abort=True)
+            except Exception as exception:
+                _echo_error(
+                    'an exception occurred while trying to discover archives at URL {}'.format(webpage),
+                    non_interactive=non_interactive,
+                    more_archives=webpage != webpages[-1] or archives_file or archives_url,
+                    raised_exception=exception
+                )
             else:
                 echo.echo_success('{} archive URLs discovered and added'.format(len(urls)))
                 archives_url += urls
@@ -239,7 +289,8 @@ def cmd_import(
         'extras_mode_existing': ExtrasImportCode[extras_mode_existing].value,
         'extras_mode_new': extras_mode_new,
         'comment_mode': comment_mode,
-        'non_interactive': non_interactive
+        'non_interactive': non_interactive,
+        'silent': False,
     }
 
     # Import local archives
@@ -250,6 +301,7 @@ def cmd_import(
         # Initialization
         import_opts['archive'] = archive
         import_opts['file_to_import'] = import_opts['archive']
+        import_opts['more_archives'] = archive != archives_file[-1] or archives_url
 
         # First attempt to import archive
         migrate_archive = _try_import(migration_performed=False, **import_opts)
@@ -265,13 +317,14 @@ def cmd_import(
 
         # Initialization
         import_opts['archive'] = archive
+        import_opts['more_archives'] = archive != archives_url[-1]
 
         echo.echo_info('downloading archive {}'.format(archive))
 
         try:
             response = urllib.request.urlopen(archive)
         except Exception as exception:
-            echo.echo_warning('downloading archive {} failed: {}'.format(archive, exception))
+            _echo_error('downloading archive {} failed'.format(archive), raised_exception=exception, **import_opts)
 
         with SandboxFolder() as temp_folder:
             temp_file = 'importfile.tar.gz'
