@@ -9,16 +9,16 @@
 ###########################################################################
 # pylint: disable=wildcard-import,undefined-variable,redefined-builtin
 """Module for processes and related utilities."""
-
 from .builder import *
 from .calcjobs import *
 from .exit_code import *
 from .functions import *
 from .ports import *
 from .process import *
+from .process_spec import *
 from .workchains import *
 
 __all__ = (
     builder.__all__ + calcjobs.__all__ + exit_code.__all__ + functions.__all__ + ports.__all__ + process.__all__ +
-    workchains.__all__
+    process_spec.__all__ + workchains.__all__
 )
