@@ -173,8 +173,8 @@ class SqlaCommentCollection(BackendCommentCollection):
             raise exceptions.ValidationError('filters must not be empty')
 
         # Apply filter and delete found entities
-        builder = QueryBuilder().append(Comment, filters=filters, project='id').all()
-        entities_to_delete = [_[0] for _ in builder]
+        builder = QueryBuilder().append(Comment, filters=filters, project='id')
+        entities_to_delete = builder.all(flat=True)
         for entity in entities_to_delete:
             self.delete(entity)
 
