@@ -825,7 +825,7 @@ class BandsData(KpointsData):
 
         s_header = matplotlib_header_template.substitute()
         s_import = matplotlib_import_data_inline_template.substitute(all_data_json=json.dumps(all_data, indent=2))
-        s_body = matplotlib_body_template.substitute()
+        s_body = self._get_mpl_body_template(all_data['paths'])
         s_footer = matplotlib_footer_template_show.substitute()
 
         s = s_header + s_import + s_body + s_footer
@@ -854,15 +854,138 @@ class BandsData(KpointsData):
 
         s_header = matplotlib_header_template.substitute()
         s_import = matplotlib_import_data_fromfile_template.substitute(json_fname=json_fname)
-        s_body = matplotlib_body_template.substitute()
+        s_body = self._get_mpl_body_template(all_data['paths'])
         s_footer = matplotlib_footer_template_show.substitute()
 
         s = s_header + s_import + s_body + s_footer
 
         return s.encode('utf-8'), ext_files
 
+    def _prepare_mpl_pdf(self, main_file_name='', *args, **kwargs):
+        """
+        Prepare a python script using matplotlib to plot the bands, with the JSON
+        returned as an independent file.
+
+        For the possible parameters, see documentation of
+        :py:meth:`~aiida.orm.nodes.data.array.bands.BandsData._matplotlib_get_dict`
+        """
+        import os
+        import tempfile
+        import subprocess
+        import sys
+
+        from aiida.common import json
+
+        all_data = self._matplotlib_get_dict(*args, **kwargs)
+
+        # Use the Agg backend
+        s_header = matplotlib_header_agg_template.substitute()
+        s_import = matplotlib_import_data_inline_template.substitute(all_data_json=json.dumps(all_data, indent=2))
+        s_body = self._get_mpl_body_template(all_data['paths'])
+
+        # I get a temporary file name
+        handle, filename = tempfile.mkstemp()
+        os.close(handle)
+        os.remove(filename)
+
+        escaped_fname = filename.replace('"', '\"')
+
+        s_footer = matplotlib_footer_template_exportfile.substitute(fname=escaped_fname, format='pdf')
+
+        s = s_header + s_import + s_body + s_footer
+
+        # I don't exec it because I might mess up with the matplotlib backend etc.
+        # I run instead in a different process, with the same executable
+        # (so it should work properly with virtualenvs)
+        #exec s
+        with tempfile.NamedTemporaryFile(mode='w+') as f:
+            f.write(s)
+            f.flush()
+
+            subprocess.check_output([sys.executable, f.name])
+
+        if not os.path.exists(filename):
+            raise RuntimeError('Unable to generate the PDF...')
+
+        with open(filename, 'rb', encoding=None) as f:
+            imgdata = f.read()
+        os.remove(filename)
+
+        return imgdata, {}
+
+    def _prepare_mpl_png(self, main_file_name='', *args, **kwargs):
+        """
+        Prepare a python script using matplotlib to plot the bands, with the JSON
+        returned as an independent file.
+
+        For the possible parameters, see documentation of
+        :py:meth:`~aiida.orm.nodes.data.array.bands.BandsData._matplotlib_get_dict`
+        """
+        import json
+        import os
+        import tempfile
+        import subprocess
+        import sys
+
+        all_data = self._matplotlib_get_dict(*args, **kwargs)
+
+        # Use the Agg backend
+        s_header = matplotlib_header_agg_template.substitute()
+        s_import = matplotlib_import_data_inline_template.substitute(all_data_json=json.dumps(all_data, indent=2))
+        s_body = self._get_mpl_body_template(all_data['paths'])
+
+        # I get a temporary file name
+        handle, filename = tempfile.mkstemp()
+        os.close(handle)
+        os.remove(filename)
+
+        escaped_fname = filename.replace('"', '\"')
+
+        s_footer = matplotlib_footer_template_exportfile_with_dpi.substitute(fname=escaped_fname, format='png', dpi=300)
+
+        s = s_header + s_import + s_body + s_footer
+
+        # I don't exec it because I might mess up with the matplotlib backend etc.
+        # I run instead in a different process, with the same executable
+        # (so it should work properly with virtualenvs)
+        with tempfile.NamedTemporaryFile(mode='w+') as f:
+            f.write(s)
+            f.flush()
+
+            subprocess.check_output([sys.executable, f.name])
+
+        if not os.path.exists(filename):
+            raise RuntimeError('Unable to generate the PNG...')
+
+        with open(filename, 'rb', encoding=None) as f:
+            imgdata = f.read()
+        os.remove(filename)
+
+        return imgdata, {}
+
+    @staticmethod
+    def _get_mpl_body_template(paths):
+        """
+        :param paths: paths of k-points
+        """
+        if len(paths) == 1:
+            s_body = matplotlib_body_template.substitute(plot_code=single_kp)
+        else:
+            s_body = matplotlib_body_template.substitute(plot_code=multi_kp)
+        return s_body
+
+    def show_mpl(self, **kwargs):
+        """
+        Call a show() command for the band structure using matplotlib.
+        This uses internally the 'mpl_singlefile' format, with empty
+        main_file_name.
+
+        Other kwargs are passed to self._exportcontent.
+        """
+        exec(*self._exportcontent(fileformat='mpl_singlefile', main_file_name='', **kwargs))  # pylint: disable=exec-used
+
     def _prepare_gnuplot(self,
-                         main_file_name='',
+                         main_file_name=None,
                          title='',
                          comments=True,
                          prettify_format=None,
@@ -885,6 +1008,7 @@ class BandsData(KpointsData):
         """
         import os
 
+        main_file_name = main_file_name or 'band.dat'
         dat_filename = os.path.splitext(main_file_name)[0] + '_data.dat'
 
         if prettify_format is None:
@@ -942,11 +1066,10 @@ class BandsData(KpointsData):
         script.append('set termopt enhanced')  # Properly deals with e.g. subscripts
         script.append('set encoding utf8')  # To deal with Greek letters
         script.append('set xtics ({})'.format(xtics_string))
-        script.append('set grid xtics lt 1 lc rgb "#888888"')
 
         script.append('unset key')
 
-        script.append('set xrange [{}:{}]'.format(x_min_lim, x_max_lim))
+
         script.append('set yrange [{}:{}]'.format(y_min_lim, y_max_lim))
 
         script.append('set ylabel "{}"'.format('Dispersion ({})'.format(self.units)))
@@ -955,125 +1078,19 @@ class BandsData(KpointsData):
             script.append('set title "{}"'.format(title.replace('"', '\"')))
 
         # Plot, escaping filename
-        script.append('plot "{}" with l lc rgb "#000000"'.format(os.path.basename(dat_filename).replace('"', '\"')))
+        if len(x) > 1:
+            script.append('set xrange [{}:{}]'.format(x_min_lim, x_max_lim))
+            script.append('set grid xtics lt 1 lc rgb "#888888"')
+            script.append('plot "{}" with l lc rgb "#000000"'.format(os.path.basename(dat_filename).replace('"', '\"')))
+        else:
+            script.append('set xrange [-1.0:1.0]')
+            script.append('plot "{}" using ($1-0.25):($2):(0.5):(0) with vectors nohead lc rgb "#000000"'.format(os.path.basename(dat_filename).replace('"', '\"')))
 
         script_data = '\n'.join(script) + '\n'
         extra_files = {dat_filename: raw_data}
 
         return script_data.encode('utf-8'), extra_files
 
-    def _prepare_mpl_pdf(self, main_file_name='', *args, **kwargs):
-        """
-        Prepare a python script using matplotlib to plot the bands, with the JSON
-        returned as an independent file.
-
-        For the possible parameters, see documentation of
-        :py:meth:`~aiida.orm.nodes.data.array.bands.BandsData._matplotlib_get_dict`
-        """
-        import os
-        import tempfile
-        import subprocess
-        import sys
-
-        from aiida.common import json
-
-        all_data = self._matplotlib_get_dict(*args, **kwargs)
-
-        # Use the Agg backend
-        s_header = matplotlib_header_agg_template.substitute()
-        s_import = matplotlib_import_data_inline_template.substitute(all_data_json=json.dumps(all_data, indent=2))
-        s_body = matplotlib_body_template.substitute()
-
-        # I get a temporary file name
-        handle, filename = tempfile.mkstemp()
-        os.close(handle)
-        os.remove(filename)
-
-        escaped_fname = filename.replace('"', '\"')
-
-        s_footer = matplotlib_footer_template_exportfile.substitute(fname=escaped_fname, format='pdf')
-
-        s = s_header + s_import + s_body + s_footer
-
-        # I don't exec it because I might mess up with the matplotlib backend etc.
-        # I run instead in a different process, with the same executable
-        # (so it should work properly with virtualenvs)
-        #exec s
-        with tempfile.NamedTemporaryFile(mode='w+') as f:
-            f.write(s)
-            f.flush()
-
-            subprocess.check_output([sys.executable, f.name])
-
-        if not os.path.exists(filename):
-            raise RuntimeError('Unable to generate the PDF...')
-
-        with open(filename, 'rb', encoding=None) as f:
-            imgdata = f.read()
-        os.remove(filename)
-
-        return imgdata, {}
-
-    def _prepare_mpl_png(self, main_file_name='', *args, **kwargs):
-        """
-        Prepare a python script using matplotlib to plot the bands, with the JSON
-        returned as an independent file.
-
-        For the possible parameters, see documentation of
-        :py:meth:`~aiida.orm.nodes.data.array.bands.BandsData._matplotlib_get_dict`
-        """
-        import json
-        import os
-        import tempfile
-        import subprocess
-        import sys
-
-        all_data = self._matplotlib_get_dict(*args, **kwargs)
-
-        # Use the Agg backend
-        s_header = matplotlib_header_agg_template.substitute()
-        s_import = matplotlib_import_data_inline_template.substitute(all_data_json=json.dumps(all_data, indent=2))
-        s_body = matplotlib_body_template.substitute()
-
-        # I get a temporary file name
-        handle, filename = tempfile.mkstemp()
-        os.close(handle)
-        os.remove(filename)
-
-        escaped_fname = filename.replace('"', '\"')
-
-        s_footer = matplotlib_footer_template_exportfile_with_dpi.substitute(fname=escaped_fname, format='png', dpi=300)
-
-        s = s_header + s_import + s_body + s_footer
-
-        # I don't exec it because I might mess up with the matplotlib backend etc.
-        # I run instead in a different process, with the same executable
-        # (so it should work properly with virtualenvs)
-        with tempfile.NamedTemporaryFile(mode='w+') as f:
-            f.write(s)
-            f.flush()
-
-            subprocess.check_output([sys.executable, f.name])
-
-        if not os.path.exists(filename):
-            raise RuntimeError('Unable to generate the PNG...')
-
-        with open(filename, 'rb', encoding=None) as f:
-            imgdata = f.read()
-        os.remove(filename)
-
-        return imgdata, {}
-
-    def show_mpl(self, **kwargs):
-        """
-        Call a show() command for the band structure using matplotlib.
-        This uses internally the 'mpl_singlefile' format, with empty
-        main_file_name.
-
-        Other kwargs are passed to self._exportcontent.
-        """
-        exec(*self._exportcontent(fileformat='mpl_singlefile', main_file_name='', **kwargs))  # pylint: disable=exec-used
-
     def _prepare_agr(self,
                      main_file_name='',
                      comments=True,
@@ -1646,6 +1663,42 @@ matplotlib_import_data_fromfile_template = Template('''with open("$json_fname",
     all_data_str = f.read()
 ''')
 
+multi_kp = '''
+for path in paths:
+    if path['length'] <= 1:
+        # Avoid printing empty lines
+        continue
+    x = path['x']
+    #for band in bands:
+    for band, band_type in zip(path['values'], all_data['band_type_idx']):
+
+        # For now we support only two colors
+        if band_type % 2 == 0:
+            further_plot_options = further_plot_options1
+        else:
+            further_plot_options = further_plot_options2
+
+        # Put the legend text only once
+        label = None
+        if first_band_1 and band_type % 2 == 0:
+            first_band_1 = False
+            label = all_data.get('legend_text', None)
+        elif first_band_2 and band_type % 2 == 1:
+            first_band_2 = False
+            label = all_data.get('legend_text2', None)
+
+        p.plot(x, band, label=label,
+               **further_plot_options
+        )
+'''
+
+single_kp = '''
+path = paths[0]
+values = path['values']
+x = [path['x'] for _ in values]
+p.scatter(x, values, marker="_")
+'''
+
 matplotlib_body_template = Template('''all_data = json.loads(all_data_str)
 
 if not all_data.get('use_latex', False):
@@ -1700,33 +1753,7 @@ p = fig.add_subplot(1,1,1)
 first_band_1 = True
 first_band_2 = True
 
-for path in paths:
-    if path['length'] <= 1:
-        # Avoid printing empty lines
-        continue
-    x = path['x']
-    #for band in bands:
-    for band, band_type in zip(path['values'], all_data['band_type_idx']):
-
-        # For now we support only two colors
-        if band_type % 2 == 0:
-            further_plot_options = further_plot_options1
-        else:
-            further_plot_options = further_plot_options2
-
-        # Put the legend text only once
-        label = None
-        if first_band_1 and band_type % 2 == 0:
-            first_band_1 = False
-            label = all_data.get('legend_text', None)
-        elif first_band_2 and band_type % 2 == 1:
-            first_band_2 = False
-            label = all_data.get('legend_text2', None)
-
-        p.plot(x, band, label=label,
-               **further_plot_options
-        )
-
+${plot_code}
 
 p.set_xticks(tick_pos)
 p.set_xticklabels(tick_labels)
