@@ -7,50 +7,33 @@
 # For further information on the license, see the LICENSE.txt file        #
 # For further information please visit http://www.aiida.net               #
 ###########################################################################
-from aiida.common import exceptions
+# pylint: disable=inconsistent-return-statements
+# Warning: this implementation is used directly in the documentation as a literal-include, which means that if any part
+# of this code is changed, the snippets in the file `docs/source/howto/codes.rst` have to be checked for consistency.
+"""Parser for an `ArithmeticAddCalculation` job."""
 from aiida.orm import Int
 from aiida.parsers.parser import Parser
 
 
 class ArithmeticAddParser(Parser):
+    """Parser for an `ArithmeticAddCalculation` job."""
 
     def parse(self, **kwargs):
-        """Parse the contents of the output files retrieved in the `FolderData`."""
+        """Parse the contents of the output files stored in the `retrieved` output node."""
         try:
             output_folder = self.retrieved
-        except exceptions.NotExistent:
+        except AttributeError:
             return self.exit_codes.ERROR_NO_RETRIEVED_FOLDER
 
         try:
-            with output_folder.open(self.node.get_attribute('output_filename'), 'r') as handle:
-                result = self.parse_stdout(handle)
-        except (OSError, IOError):
+            with output_folder.open(self.node.get_option('output_filename'), 'r') as handle:
+                result = int(handle.read())
+        except OSError:
             return self.exit_codes.ERROR_READING_OUTPUT_FILE
-
-        if result is None:
+        except ValueError:
             return self.exit_codes.ERROR_INVALID_OUTPUT
 
-        try:
-            allow_negative = self.node.inputs.settings.get_attribute('allow_negative', True)
-        except exceptions.NotExistent:
-            allow_negative = True
-
-        if not allow_negative and result < 0:
+        if result < 0:
             return self.exit_codes.ERROR_NEGATIVE_NUMBER
 
         self.out('sum', Int(result))
-
-    @staticmethod
-    def parse_stdout(filelike):
-        """
-        Parse the sum from the output of the ArithmeticAddcalculation written to standard out
-
-        :param filelike: filelike object containing the output
-        :returns: the sum
-        """
-        try:
-            result = int(filelike.read())
-        except ValueError:
-            result = None
-
-        return result
